=====================
Developers' Reference
=====================

The score module
----------------

.. automodule:: ms3.score
    :members: Score, MSCX

The annotations module
----------------------

.. automodule:: ms3.annotations
    :members: Annotations

The parse module
----------------

.. automodule:: ms3.parse
    :members: Parse